--[[
This addon adds a filter possibility to the Tradeskill window.

This will only show recipes that have a chance to give a skillup. This makes it easier 
to find  those recipies that will inprove your Tradeskill level, but are lower in the list.
]]--


-- Language stuff
local CRAFT_SKILLUPS_ONLY_TOOLTIP = "Only show recipes that have a chance to increase your skill."


-- Create a new button
local but = CreateFrame("CheckButton", "TradeSkillIncreaseFilterButton", TradeSkillFrame, "UICheckButtonTemplate")


-- Setup sizes and textures
but:SetWidth(21)
but:SetHeight(21)
but:SetNormalTexture("Interface\\Addons\\OnlySkillups\\Button-OnlySkillups-Disabled")
but:SetPushedTexture("Interface\\Addons\\OnlySkillups\\Button-OnlySkillups-Enabled")
but:SetCheckedTexture("Interface\\Addons\\OnlySkillups\\Button-OnlySkillups-Enabled")

-- Event handling
but:SetScript("OnEvent", function(self, event, arg1)
	local tradeskillName = GetTradeSkillLine()

	if (event=="TRADE_SKILL_SHOW") then
		-- Make sure there is always a settings for this
		OnlySkillupsEnabled[tradeskillName] = OnlySkillupsEnabled[tradeskillName] or false

		-- Could have switched tradeskill, update the button to last state for this tradeskill
		self:SetChecked(OnlySkillupsEnabled[tradeskillName])
		TradeSkillOnlyShowSkillUps(OnlySkillupsEnabled[tradeskillName])
	elseif (event=="ADDON_LOADED") then
		if (arg1 == "OnlySkillups") then
			-- Check if upgrade is needed for SV vars
			if (type(OnlySkillupsEnabled) ~= "table") then
				OnlySkillupsEnabled = {}
			end

			-- Make sure there is always a settings for this tradeskill
			OnlySkillupsEnabled[tradeskillName] = OnlySkillupsEnabled[tradeskillName] or false

			-- Initial setting, just to make sure all is in sync
			self:SetChecked(OnlySkillupsEnabled[tradeskillName])
			TradeSkillOnlyShowSkillUps(OnlySkillupsEnabled[tradeskillName])

			-- Done with the event
			self:UnregisterEvent("ADDON_LOADED")

			-- Register for show so we can update the button when the tradeskill window is shown
			self:RegisterEvent("TRADE_SKILL_SHOW")
		end
	end
end)
but:RegisterEvent("ADDON_LOADED")


-- Click handling (just toggle setting based on current setting)
but:SetScript("OnClick", function(self,button)
	local tradeskillName = GetTradeSkillLine()

	OnlySkillupsEnabled[tradeskillName] = self:GetChecked()
	TradeSkillOnlyShowSkillUps(OnlySkillupsEnabled[tradeskillName])
end)


-- Tooltip handling
but:SetScript("OnEnter", function(self)
	GameTooltip:SetOwner(self, "ANCHOR_LEFT")
	GameTooltip:SetText(CRAFT_SKILLUPS_ONLY_TOOLTIP, nil, nil, nil, nil, 1)
end)
but:SetScript("OnLeave", function(self)
	GameTooltip:Hide()
end)


-- Put button the place where the "Have materials" checkbox is now
but:ClearAllPoints()
but:SetPoint("TOPLEFT", TradeSkillFrame , "TOPLEFT", 71, -47)


-- Re-anchor "Have materials" checkbox to this button
TradeSkillFrameAvailableFilterCheckButton:SetPoint("TOPLEFT", but, "TOPRIGHT", -3, 1)

